Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(824)

Unified Diff: ash/root_window_controller.h

Issue 14340007: Hide the tab indicators and the shelf when in immersive + tab fullscreen (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Removed kImmersiveModeKey Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | ash/root_window_controller.cc » ('j') | chrome/browser/fullscreen_chromeos.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/root_window_controller.h
diff --git a/ash/root_window_controller.h b/ash/root_window_controller.h
index 1bd6ae8ca0610c05cc1da4f7c449faef7ac90fd0..1da3d8b492ba06aa6f6ce5246d47c629161085b7 100644
--- a/ash/root_window_controller.h
+++ b/ash/root_window_controller.h
@@ -169,9 +169,10 @@ class ASH_EXPORT RootWindowController {
// Force the shelf to query for it's current visibility state.
void UpdateShelfVisibility();
- // Returns true if the active workspace is in immersive mode. Exposed here
- // so clients of Ash don't need to know the details of workspace management.
- bool IsImmersiveMode() const;
+ // Returns the window, if any, which is in fullscreen mode in the active
+ // workspace. Exposed here so clients of Ash don't need to know the details
+ // of workspace management.
+ aura::Window* GetFullscreenWindow() const;
private:
// Creates each of the special window containers that holds windows of various
« no previous file with comments | « no previous file | ash/root_window_controller.cc » ('j') | chrome/browser/fullscreen_chromeos.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698